/* Generated by /usr/obj/ports/pidgin-2.14.14/pidgin-2.14.14/libpurple/dbus-analyze-types.py.  Do not edit! */
PURPLE_DBUS_DECLARE_TYPE(PurpleAccountUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleAccountPrefsUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleAccount)
PURPLE_DBUS_DECLARE_TYPE(PurpleAccountOption)
PURPLE_DBUS_DECLARE_TYPE(PurpleAccountUserSplit)
PURPLE_DBUS_DECLARE_TYPE(PurpleBuddyList)
PURPLE_DBUS_DECLARE_TYPE(PurpleBlistUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleBlistNode)
PURPLE_DBUS_DECLARE_TYPE(PurpleChat)
PURPLE_DBUS_DECLARE_TYPE(PurpleGroup)
PURPLE_DBUS_DECLARE_TYPE(PurpleContact)
PURPLE_DBUS_DECLARE_TYPE(PurpleBuddy)
PURPLE_DBUS_DECLARE_TYPE(PurpleBuddyIcon)
PURPLE_DBUS_DECLARE_TYPE(PurpleCertificate)
PURPLE_DBUS_DECLARE_TYPE(PurpleCertificatePool)
PURPLE_DBUS_DECLARE_TYPE(PurpleCertificateScheme)
PURPLE_DBUS_DECLARE_TYPE(PurpleCertificateVerifier)
PURPLE_DBUS_DECLARE_TYPE(PurpleCertificateVerificationRequest)
PURPLE_DBUS_DECLARE_TYPE(PurpleCipher)
PURPLE_DBUS_DECLARE_TYPE(PurpleCipherOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleCipherContext)
PURPLE_DBUS_DECLARE_TYPE(PurpleCircBuffer)
PURPLE_DBUS_DECLARE_TYPE(PurpleCmd)
PURPLE_DBUS_DECLARE_TYPE(PurpleCommandsUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleConnection)
PURPLE_DBUS_DECLARE_TYPE(PurpleConnectionErrorInfo)
PURPLE_DBUS_DECLARE_TYPE(PurpleConnectionUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleConversationUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleConversation)
PURPLE_DBUS_DECLARE_TYPE(PurpleConvIm)
PURPLE_DBUS_DECLARE_TYPE(PurpleConvChat)
PURPLE_DBUS_DECLARE_TYPE(PurpleConvChatBuddy)
PURPLE_DBUS_DECLARE_TYPE(PurpleConvMessage)
PURPLE_DBUS_DECLARE_TYPE(PurpleCore)
PURPLE_DBUS_DECLARE_TYPE(PurpleCoreUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleDebugUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleDesktopItem)
PURPLE_DBUS_DECLARE_TYPE(PurpleEventLoopUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleXfer)
PURPLE_DBUS_DECLARE_TYPE(PurpleXferUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleIdleUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleStoredImage)
PURPLE_DBUS_DECLARE_TYPE(PurpleLog)
PURPLE_DBUS_DECLARE_TYPE(PurpleLogLogger)
PURPLE_DBUS_DECLARE_TYPE(PurpleLogCommonLoggerData)
PURPLE_DBUS_DECLARE_TYPE(PurpleLogSet)
PURPLE_DBUS_DECLARE_TYPE(PurpleMedia)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaElementInfo)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaElementInfoClass)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaManager)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaManagerClass)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaAppDataCallbacks)
PURPLE_DBUS_DECLARE_TYPE(PurpleMimeDocument)
PURPLE_DBUS_DECLARE_TYPE(PurpleMimePart)
PURPLE_DBUS_DECLARE_TYPE(PurpleNetworkListenData)
PURPLE_DBUS_DECLARE_TYPE(PurpleNotifyUserInfoEntry)
PURPLE_DBUS_DECLARE_TYPE(PurpleNotifyUserInfo)
PURPLE_DBUS_DECLARE_TYPE(PurpleNotifySearchResults)
PURPLE_DBUS_DECLARE_TYPE(PurpleNotifySearchColumn)
PURPLE_DBUS_DECLARE_TYPE(PurpleNotifySearchButton)
PURPLE_DBUS_DECLARE_TYPE(PurpleNotifyUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurplePlugin)
PURPLE_DBUS_DECLARE_TYPE(PurplePluginInfo)
PURPLE_DBUS_DECLARE_TYPE(PurplePluginUiInfo)
PURPLE_DBUS_DECLARE_TYPE(PurplePluginLoaderInfo)
PURPLE_DBUS_DECLARE_TYPE(PurplePluginAction)
PURPLE_DBUS_DECLARE_TYPE(PurplePluginPrefFrame)
PURPLE_DBUS_DECLARE_TYPE(PurplePluginPref)
PURPLE_DBUS_DECLARE_TYPE(PurplePounce)
PURPLE_DBUS_DECLARE_TYPE(PurplePrefCallbackData)
PURPLE_DBUS_DECLARE_TYPE(PurplePrefsUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurplePrivacyUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleProxyInfo)
PURPLE_DBUS_DECLARE_TYPE(PurpleProxyConnectData)
PURPLE_DBUS_DECLARE_TYPE(PurplePluginProtocolInfo)
PURPLE_DBUS_DECLARE_TYPE(PurpleAttentionType)
PURPLE_DBUS_DECLARE_TYPE(PurpleBuddyIconSpec)
PURPLE_DBUS_DECLARE_TYPE(PurpleThumbnailSpec)
PURPLE_DBUS_DECLARE_TYPE(PurpleRequestField)
PURPLE_DBUS_DECLARE_TYPE(PurpleRequestFields)
PURPLE_DBUS_DECLARE_TYPE(PurpleRequestFieldGroup)
PURPLE_DBUS_DECLARE_TYPE(PurpleRequestUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleRoomlist)
PURPLE_DBUS_DECLARE_TYPE(PurpleRoomlistRoom)
PURPLE_DBUS_DECLARE_TYPE(PurpleRoomlistField)
PURPLE_DBUS_DECLARE_TYPE(PurpleRoomlistUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleSavedStatus)
PURPLE_DBUS_DECLARE_TYPE(PurpleSavedStatusSub)
PURPLE_DBUS_DECLARE_TYPE(PurpleSmiley)
PURPLE_DBUS_DECLARE_TYPE(PurpleSmileyClass)
PURPLE_DBUS_DECLARE_TYPE(PurpleDnsQueryData)
PURPLE_DBUS_DECLARE_TYPE(PurpleDnsQueryUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleSrvTxtQueryData)
PURPLE_DBUS_DECLARE_TYPE(PurpleSrvResponse)
PURPLE_DBUS_DECLARE_TYPE(PurpleTxtResponse)
PURPLE_DBUS_DECLARE_TYPE(PurpleSrvQueryData)
PURPLE_DBUS_DECLARE_TYPE(PurpleSrvTxtQueryUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleStatusType)
PURPLE_DBUS_DECLARE_TYPE(PurpleStatusAttr)
PURPLE_DBUS_DECLARE_TYPE(PurplePresence)
PURPLE_DBUS_DECLARE_TYPE(PurpleStatus)
PURPLE_DBUS_DECLARE_TYPE(PurpleMood)
PURPLE_DBUS_DECLARE_TYPE(PurpleStringref)
PURPLE_DBUS_DECLARE_TYPE(PurpleStunNatDiscovery)
PURPLE_DBUS_DECLARE_TYPE(PurpleSoundUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleSoundTheme)
PURPLE_DBUS_DECLARE_TYPE(PurpleSoundThemeClass)
PURPLE_DBUS_DECLARE_TYPE(PurpleSoundThemeLoader)
PURPLE_DBUS_DECLARE_TYPE(PurpleSoundThemeLoaderClass)
PURPLE_DBUS_DECLARE_TYPE(PurpleSslConnection)
PURPLE_DBUS_DECLARE_TYPE(PurpleSslOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleTheme)
PURPLE_DBUS_DECLARE_TYPE(PurpleThemeClass)
PURPLE_DBUS_DECLARE_TYPE(PurpleThemeLoader)
PURPLE_DBUS_DECLARE_TYPE(PurpleThemeLoaderClass)
PURPLE_DBUS_DECLARE_TYPE(PurpleThemeManager)
PURPLE_DBUS_DECLARE_TYPE(PurpleThemeManagerClass)
PURPLE_DBUS_DECLARE_TYPE(UPnPMappingAddRemove)
PURPLE_DBUS_DECLARE_TYPE(PurpleUtilFetchUrlData)
PURPLE_DBUS_DECLARE_TYPE(PurpleMenuAction)
PURPLE_DBUS_DECLARE_TYPE(PurpleKeyValuePair)
PURPLE_DBUS_DECLARE_TYPE(PurpleValue)
PURPLE_DBUS_DECLARE_TYPE(xmlnode)
PURPLE_DBUS_DECLARE_TYPE(PurpleWhiteboardPrplOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleWhiteboard)
PURPLE_DBUS_DECLARE_TYPE(PurpleWhiteboardUiOps)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaBackend)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaBackendIface)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaCandidate)
PURPLE_DBUS_DECLARE_TYPE(PurpleMediaCodec)
